package kieker.webgui.beans;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;
import kieker.analysis.AnalysisController;
import kieker.analysis.model.analysisMetaModel.MIProject;
import kieker.analysis.model.analysisMetaModel.impl.MAnalysisMetaModelFactory;
import org.primefaces.model.DefaultTreeNode;
import org.primefaces.model.TreeNode;

/**
 * This bean can be used to handle all available projects within the program.
 *
 * @author Nils Christian Ehmke
 */
@ManagedBean
@ApplicationScoped
public class AvailableProjectsBean {

    private final List<MIProject> projects;
    private final MAnalysisMetaModelFactory factory;

    public AvailableProjectsBean() {
        projects = new ArrayList<MIProject>();
        factory = new MAnalysisMetaModelFactory();
    }

    public synchronized boolean addProject(final String projectName) {
        final MIProject project = factory.createProject();
        project.setName(projectName);
      

        try {
            File f = new File(projectName + ".xml");
            System.out.println(f.getAbsolutePath());
            new AnalysisController(project).saveToFile(f, projectName);
        } catch (Exception ex) {
            System.out.println(ex);
        }

        

        return projects.add(project);
    }

    public synchronized TreeNode getProjectsRoot() {
        TreeNode root = new DefaultTreeNode("Root", null);

        for (final MIProject project : projects) {
            final TreeNode projectNode = new DefaultTreeNode("project", project, root);
            final TreeNode dependenciesNode = new DefaultTreeNode("dependencies", "Dependencies", projectNode);
            final TreeNode usedPluginsNode = new DefaultTreeNode("usedPlugins", "Used Plugins", projectNode);
        }

        return root;
    }
}
